@@ -668,7 +668,7 @@ class Ghettovcb(Archiver):
             else:
                 find_src=root_backup_dir
 
-            find_cmd='find "%s" -type f -exec stat -c "%%s:%%Y:%%n" {} \;' % (find_src, )
+            find_cmd='find "%s" -type f -exec stat -c "%%b:%%s:%%Y:%%Z:%%n" {} \;' % (find_src, )
 
             start=time.time()
             status='OK'
@@ -681,12 +681,12 @@ class Ghettovcb(Archiver):
             finished=False
             while not finished:
                 # get epoch from ESX(i)
-                time.sleep(10)
+                time.sleep(15)
                 exit_code, output=RunCommand(self.t, 'date +%s', log=None)
                 if exit_code:
                     self.log.error('cannot get epoch: %r', output)
                     return False
-                
+
                 finished=current_vm in self.finished_vm
                 # print 'ASX finished', current_vm, finished
                 esx_epoch=int(output.split('\n')[0])
@@ -711,17 +711,17 @@ class Ghettovcb(Archiver):
                 for line in output.split('\n'):
                     if not line:
                         continue
-                    size, epoch, filename=line.split(':', 2)
+                    block_number, size, c_epoch, m_epoch, filename=line.split(':', 5)
                     if filename.startswith('.lck-'):
                         continue
-                    files[filename]=(int(size), int(epoch), line)
+                    
+                    files[filename]=(max(int(c_epoch), int(m_epoch)), line)
                          
-                for filename, (size, epoch, line) in files.iteritems():
+                for filename, (epoch, line) in files.iteritems():
                     if line in self.uploaded_filenames:
                         continue
                     if not finished:
-                        size, epoch=int(size), int(epoch)
-                        if epoch+60>esx_epoch and current_vm not in self.finished_vm:
+                        if epoch+30>esx_epoch and current_vm not in self.finished_vm:
                             # file last modified < 30s ago, skip 
                             continue
 
@@ -729,7 +729,7 @@ class Ghettovcb(Archiver):
                         if match:
                             number=int(match.group('number'))
                             previous_part=filename[:match.start('number')]+'%03d' % (number-1, )+filename[match.end('number'):]
-                            if previous_part in files and files[previous_part][2] not in self.uploaded_filenames:
+                            if previous_part in files and files[previous_part][-1] not in self.uploaded_filenames:
                                 # part of 2gbsparse but previous part not yet uploaded
                                 continue
 
